package friends

import (
	usercenter "server/datacenter"
	requestaddfriend "server/datacenter/request_add_friend"
	agentmanager "server/game/agentManager"
	"server/msg"

	"github.com/name5566/leaf/gate"
)

// 获取用户的好友列表
func GetFriendsListByUserId(args []interface{}) {
	m := args[0].(*msg.ReqFriendList)
	a := args[1].(gate.Agent)
	list, err := requestaddfriend.GetPendingRequests(m.UserId)
	if err != nil {
		a.WriteMsg(&msg.ResFriendList{
			Success: false,
			ErrMsg: &msg.MsgError{
				ErrorCode: 101,
				ErrorMsg:  err.Error(),
			},
		})
		return
	}
	var temp = make([]*msg.RequestAddFriendItem, 0)
	for _, v := range list {
		temp = append(temp, &msg.RequestAddFriendItem{
			Id:         int32(v.ID),
			RequestID:  v.RequestID,
			FromUserID: v.FromUserID,
			ToUserID:   v.ToUserID,
			Status:     int32(v.Status),
			Message:    v.Message,
		})
	}
	a.WriteMsg(&msg.ResFriendList{
		Success: true,
		ErrMsg:  nil,
		List:    temp,
	})

}

// 添加好友请求
func AddFriendrRquest(args []interface{}) {
	m := args[0].(*msg.ReqAddFriend)
	a := args[1].(gate.Agent)
	FromUserID := a.UserData().(*msg.UserInfo).UserId
	ToUserID := m.ToUserID
	requestaddfriend.CreateFriendRequest(FromUserID, ToUserID, m.Msg)
	NotifyFriendAddFriend(ToUserID)
}

// 通知添加好友请求
func NotifyFriendAddFriend(ToUserID string) {
	ag := agentmanager.GetAgentByUserID(ToUserID)
	if ag != nil {
		ToUserInfo := ag.UserData().(*msg.UserInfo)
		ag.WriteMsg(&msg.RecvAddFriendRequest{
			Info: &msg.UserInfo{
				MHead:  ToUserInfo.MHead,
				Name:   ToUserInfo.Name,
				UserId: ToUserInfo.UserId,
			},
		})
	}
}

// 反馈操作好友请求
func OptFriendrRquest(args []interface{}) {
	m := args[0].(*msg.OptAddFriendRequest)
	request_data, err := requestaddfriend.ProcessFriendRequest(m.Info.RequestID, int(m.Info.Status))
	if err != nil {
		request_data.Status = int(m.Info.Status)
		NotifyOptFriend(m.Info.FromUserID, request_data)
	}
}

// 通知好友操作的结果
func NotifyOptFriend(FromUserID string, request_data *requestaddfriend.FriendRequest) {
	ag := agentmanager.GetAgentByUserID(FromUserID)
	if ag != nil {
		ag.WriteMsg(&msg.NotifyOptFriend{
			Info: &msg.RequestAddFriendItem{
				Status:   int32(request_data.Status),
				ToUserID: request_data.ToUserID,
			},
		})
	}
}

// 搜索玩家
func SearchUser(args []interface{}) {
	m := args[0].(*msg.SearchUser)
	a := args[1].(gate.Agent)
	user_data, err := usercenter.GetUserByID(m.UserId)
	if err != nil {
		a.WriteMsg(&msg.ResSearchUser{
			Success: false,
			ErrMsg: &msg.MsgError{
				ErrorCode: 101,
				ErrorMsg:  err.Error(),
			},
		})
	} else {
		a.WriteMsg(&msg.ResSearchUser{
			Success: true,
			ErrMsg:  nil,
			Info: &msg.UserInfo{
				MHead: user_data.Head,
				Name:  user_data.Name,
			},
		})
	}
}

// 通知给在线的好友自己上线

// 通知给在线的好友自己下线

// 发送好友聊天消息

// 筛选在线的好友
